<template>
  <li v-if="Object.keys(locales).length > 1" class="nav-item dropdown">
    <a class="nav-link dropdown-toggle" href="#" role="button" data-bs-toggle="dropdown" aria-haspopup="true"
      aria-expanded="false">
      <span :class="'fi fi-' + locales[locale]['flag']"></span>
      {{ locales[locale]['title'] }}
    </a>
    <div class="dropdown-menu">
      <a v-for="locale in locales" :key="locale.translation" class="dropdown-item" href="#"
        @click.prevent="setLocale(locale.translation)">
        <span :class="'fi fi-' + locale.flag"></span>
        {{ locale.title }}
      </a>
    </div>
  </li>
</template>

<script>
import { mapGetters } from 'vuex'
import { loadMessages } from '~/plugins/i18n'

export default {
  computed: mapGetters({
    locale: 'lang/locale',
    locales: 'lang/locales'
  }),

  methods: {
    setLocale(locale) {
      if (this.$i18n.locale !== locale) {
        loadMessages(locale)

        this.$store.dispatch('lang/setLocale', { locale })
      }
    }
  }
}
</script>
